@@ -38,11 +38,12 @@ class AUC(Metric):
             Synchronize metric state across processes at each ``forward()``
             before returning the value at the step.
         process_group:
-            Specify the process group on which synchronization is called. default: None (which selects the entire world)
+            Specify the process group on which synchronization is called.
         dist_sync_fn:
             Callback that performs the ``allgather`` operation on the metric state. When ``None``, DDP
             will be used to perform the ``allgather``.
     """
+    is_differentiable = False
     x: List[Tensor]
     y: List[Tensor]
 
@@ -67,13 +68,12 @@ class AUC(Metric):
         self.add_state("y", default=[], dist_reduce_fx="cat")
 
         rank_zero_warn(
-            'Metric `AUC` will save all targets and predictions in buffer.'
-            ' For large datasets this may lead to large memory footprint.'
+            "Metric `AUC` will save all targets and predictions in buffer."
+            " For large datasets this may lead to large memory footprint."
         )
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
-        """
-        Update state with predictions and targets.
+        """Update state with predictions and targets.
 
         Args:
             preds: Predictions from model (probabilities, or labels)
@@ -85,17 +85,7 @@ class AUC(Metric):
         self.y.append(y)
 
     def compute(self) -> Tensor:
-        """
-        Computes AUC based on inputs passed in to ``update`` previously.
-        """
+        """Computes AUC based on inputs passed in to ``update`` previously."""
         x = dim_zero_cat(self.x)
         y = dim_zero_cat(self.y)
         return _auc_compute(x, y, reorder=self.reorder)
-
-    @property
-    def is_differentiable(self) -> bool:
-        """
-        AUC metrics is considered as non differentiable so it should have `false`
-        value for `is_differentiable` property
-        """
-        return False
