@@ -22,7 +22,7 @@ from torchmetrics.functional.classification.specificity import _specificity_comp
 
 class Specificity(StatScores):
     r"""
-    Computes `Specificity <https://en.wikipedia.org/wiki/Sensitivity_and_specificity>`_:
+    Computes `Specificity`_:
 
     .. math:: \text{Specificity} = \frac{\text{TN}}{\text{TN} + \text{FP}}
 
@@ -121,6 +121,8 @@ class Specificity(StatScores):
         tensor(0.6250)
 
     """
+    is_differentiable = False
+    higher_is_better = True
 
     def __init__(
         self,
@@ -157,8 +159,7 @@ class Specificity(StatScores):
         self.average = average
 
     def compute(self) -> Tensor:
-        """
-        Computes the specificity score based on inputs passed in to ``update`` previously.
+        """Computes the specificity score based on inputs passed in to ``update`` previously.
 
         Return:
             The shape of the returned tensor depends on the ``average`` parameter
@@ -169,7 +170,3 @@ class Specificity(StatScores):
         """
         tp, fp, tn, fn = self._get_final_stats()
         return _specificity_compute(tp, fp, tn, fn, self.average, self.mdmc_reduce)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
