@@ -14,9 +14,11 @@
 from typing import Optional
 
 import torch
+from deprecate import deprecated, void
 from torch import Tensor
 
 from torchmetrics.functional.classification.stat_scores import _reduce_stat_scores, _stat_scores_update
+from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.enums import AverageMethod as AvgMethod
 from torchmetrics.utilities.enums import MDMCAverageMethod
 
@@ -64,7 +66,6 @@ def _fbeta_compute(
         >>> _fbeta_compute(tp, fp, tn, fn, beta=0.5, ignore_index=None, average='micro', mdmc_average=None)
         tensor(0.3333)
     """
-
     if average == AvgMethod.MICRO and mdmc_average != MDMCAverageMethod.SAMPLEWISE:
         mask = tp >= 0
         precision = _safe_divide(tp[mask].sum().float(), (tp[mask] + fp[mask]).sum())
@@ -73,11 +74,6 @@ def _fbeta_compute(
         precision = _safe_divide(tp.float(), tp + fp)
         recall = _safe_divide(tp.float(), tp + fn)
 
-    if average == AvgMethod.MACRO and mdmc_average != MDMCAverageMethod.SAMPLEWISE:
-        cond = tp + fp + fn == 0
-        precision = precision[~cond]
-        recall = recall[~cond]
-
     num = (1 + beta ** 2) * precision * recall
     denom = beta ** 2 * precision + recall
     denom[denom == 0.0] = 1.0  # avoid division by 0
@@ -100,6 +96,11 @@ def _fbeta_compute(
             num[ignore_index, ...] = -1
             denom[ignore_index, ...] = -1
 
+    if average == AvgMethod.MACRO and mdmc_average != MDMCAverageMethod.SAMPLEWISE:
+        cond = (tp + fp + fn == 0) | (tp + fp + fn == -3)
+        num = num[~cond]
+        denom = denom[~cond]
+
     return _reduce_stat_scores(
         numerator=num,
         denominator=denom,
@@ -109,7 +110,7 @@ def _fbeta_compute(
     )
 
 
-def fbeta(
+def fbeta_score(
     preds: Tensor,
     target: Tensor,
     beta: float = 1.0,
@@ -208,10 +209,10 @@ def fbeta(
           of classes
 
     Example:
-        >>> from torchmetrics.functional import fbeta
+        >>> from torchmetrics.functional import fbeta_score
         >>> target = torch.tensor([0, 1, 2, 0, 1, 2])
         >>> preds = torch.tensor([0, 2, 1, 0, 0, 1])
-        >>> fbeta(preds, target, num_classes=3, beta=0.5)
+        >>> fbeta_score(preds, target, num_classes=3, beta=0.5)
         tensor(0.3333)
 
     """
@@ -244,7 +245,33 @@ def fbeta(
     return _fbeta_compute(tp, fp, tn, fn, beta, ignore_index, average, mdmc_average)
 
 
-def f1(
+@deprecated(target=fbeta_score, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
+def fbeta(
+    preds: Tensor,
+    target: Tensor,
+    beta: float = 1.0,
+    average: str = "micro",
+    mdmc_average: Optional[str] = None,
+    ignore_index: Optional[int] = None,
+    num_classes: Optional[int] = None,
+    threshold: float = 0.5,
+    top_k: Optional[int] = None,
+    multiclass: Optional[bool] = None,
+) -> Tensor:
+    r"""
+    Computes f_beta metric.
+
+    .. deprecated:: v0.7
+        Use :class:`torchmetrics.functional.f1_score`. Will be removed in v0.8.
+
+    Example::
+        >>> fbeta(torch.tensor([0, 2, 1, 0, 0, 1]), torch.tensor([0, 1, 2, 0, 1, 2]), num_classes=3, beta=0.5)
+        tensor(0.3333)
+    """
+    return void(preds, target, beta, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass)
+
+
+def f1_score(
     preds: Tensor,
     target: Tensor,
     beta: float = 1.0,
@@ -342,6 +369,36 @@ def f1(
         - If ``average in ['none', None]``, the shape will be ``(C,)``, where ``C`` stands  for the number
           of classes
 
+    Example:
+        >>> from torchmetrics.functional import f1_score
+        >>> target = torch.tensor([0, 1, 2, 0, 1, 2])
+        >>> preds = torch.tensor([0, 2, 1, 0, 0, 1])
+        >>> f1_score(preds, target, num_classes=3)
+        tensor(0.3333)
+    """
+    return fbeta_score(
+        preds, target, 1.0, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass
+    )
+
+
+@deprecated(target=f1_score, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
+def f1(
+    preds: Tensor,
+    target: Tensor,
+    beta: float = 1.0,
+    average: str = "micro",
+    mdmc_average: Optional[str] = None,
+    ignore_index: Optional[int] = None,
+    num_classes: Optional[int] = None,
+    threshold: float = 0.5,
+    top_k: Optional[int] = None,
+    multiclass: Optional[bool] = None,
+) -> Tensor:
+    """Computes F1 metric. F1 metrics correspond to a equally weighted average of the precision and recall scores.
+
+    .. deprecated:: v0.7
+        Use :class:`torchmetrics.functional.f1_score`. Will be removed in v0.8.
+
     Example:
         >>> from torchmetrics.functional import f1
         >>> target = torch.tensor([0, 1, 2, 0, 1, 2])
@@ -349,4 +406,4 @@ def f1(
         >>> f1(preds, target, num_classes=3)
         tensor(0.3333)
     """
-    return fbeta(preds, target, 1.0, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass)
+    return void(preds, target, beta, average, mdmc_average, ignore_index, num_classes, threshold, top_k, multiclass)
