@@ -109,6 +109,7 @@ class Metric(Module, ABC):
         self._computed = None
         self._forward_cache = None
         self._update_called = False
+        self._enable_grad = False
 
         # initialize state
         self._defaults: Dict[str, Union[List, Tensor]] = {}
@@ -201,8 +202,8 @@ class Metric(Module, ABC):
                 "HINT: Did you forget to call ``unsync`` ?."
             )
 
-        with torch.no_grad():
-            self.update(*args, **kwargs)
+        # global accumulation
+        self.update(*args, **kwargs)
 
         if self.compute_on_step:
             self._to_sync = self.dist_sync_on_step
@@ -213,6 +214,7 @@ class Metric(Module, ABC):
             cache = {attr: getattr(self, attr) for attr in self._defaults}
 
             # call reset, update, compute, on single batch
+            self._enable_grad = True  # allow grads for batch computation
             self.reset()
             self.update(*args, **kwargs)
             self._forward_cache = self.compute()
@@ -225,6 +227,7 @@ class Metric(Module, ABC):
             self._should_unsync = True
             self._to_sync = True
             self._computed = None
+            self._enable_grad = False
 
             return self._forward_cache
 
@@ -260,7 +263,8 @@ class Metric(Module, ABC):
         def wrapped_func(*args: Any, **kwargs: Any) -> Optional[Any]:
             self._computed = None
             self._update_called = True
-            return update(*args, **kwargs)
+            with torch.set_grad_enabled(self._enable_grad):
+                return update(*args, **kwargs)
 
         return wrapped_func
 
