@@ -11,62 +11,68 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
 from torch import Tensor
+from typing_extensions import Literal
 
 from torchmetrics import Metric
-from torchmetrics.functional.text.rouge import ALLOWED_ROUGE_KEYS, _rouge_score_compute, _rouge_score_update
+from torchmetrics.functional.text.rouge import (
+    ALLOWED_ACCUMULATE_VALUES,
+    ALLOWED_ROUGE_KEYS,
+    _rouge_score_compute,
+    _rouge_score_update,
+)
 from torchmetrics.utilities.imports import _NLTK_AVAILABLE
 
+__doctest_requires__ = {("ROUGEScore",): ["nltk"]}
+
 
 class ROUGEScore(Metric):
     """`Calculate Rouge Score`_, used for automatic summarization. This implementation should imitate the behaviour
     of the `rouge-score` package `Python ROUGE Implementation`
 
     Args:
-        newline_sep:
-            New line separate the inputs.
-            This argument has not been in use any more. It is deprecated in v0.6 and will be removed in v0.7.
         use_stemmer:
             Use Porter stemmer to strip word suffixes to improve matching.
+        accumulate:
+            Useful incase of multi-reference rouge score.
+            - ``avg`` takes the avg of all references with respect to predictions
+            - ``best`` takes the best fmeasure score obtained between prediction and multiple corresponding references.
         rouge_keys:
             A list of rouge types to calculate.
             Keys that are allowed are ``rougeL``, ``rougeLsum``, and ``rouge1`` through ``rouge9``.
-        decimal_places:
-            The number of digits to round the computed the values to.
-            This argument has not been in usd any more. It is deprecated in v0.6 and will be removed in v0.7.
         compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False. default: True
+            Forward only calls ``update()`` and returns None if this is set to False.
         dist_sync_on_step:
             Synchronize metric state across processes at each ``forward()``
             before returning the value at the step.
         process_group:
-            Specify the process group on which synchronization is called. default: None (which selects the entire world)
+            Specify the process group on which synchronization is called.
         dist_sync_fn:
             Callback that performs the allgather operation on the metric state. When `None`, DDP
             will be used to perform the allgather.
 
     Example:
-
-        >>> targets = "Is your name John"
+        >>> from torchmetrics.text.rouge import ROUGEScore
         >>> preds = "My name is John"
-        >>> rouge = ROUGEScore()   # doctest: +SKIP
+        >>> target = "Is your name John"
+        >>> rouge = ROUGEScore()
         >>> from pprint import pprint
-        >>> pprint(rouge(preds, targets))  # doctest: +NORMALIZE_WHITESPACE +SKIP
-        {'rouge1_fmeasure': 0.25,
-         'rouge1_precision': 0.25,
-         'rouge1_recall': 0.25,
-         'rouge2_fmeasure': 0.0,
-         'rouge2_precision': 0.0,
-         'rouge2_recall': 0.0,
-         'rougeL_fmeasure': 0.25,
-         'rougeL_precision': 0.25,
-         'rougeL_recall': 0.25,
-         'rougeLsum_fmeasure': 0.25,
-         'rougeLsum_precision': 0.25,
-         'rougeLsum_recall': 0.25}
+        >>> pprint(rouge(preds, target))
+        {'rouge1_fmeasure': tensor(0.7500),
+         'rouge1_precision': tensor(0.7500),
+         'rouge1_recall': tensor(0.7500),
+         'rouge2_fmeasure': tensor(0.),
+         'rouge2_precision': tensor(0.),
+         'rouge2_recall': tensor(0.),
+         'rougeL_fmeasure': tensor(0.5000),
+         'rougeL_precision': tensor(0.5000),
+         'rougeL_recall': tensor(0.5000),
+         'rougeLsum_fmeasure': tensor(0.5000),
+         'rougeLsum_precision': tensor(0.5000),
+         'rougeLsum_recall': tensor(0.5000)}
+
 
     Raises:
         ValueError:
@@ -82,10 +88,9 @@ class ROUGEScore(Metric):
 
     def __init__(
         self,
-        newline_sep: Optional[bool] = None,  # remove in v0.7
         use_stemmer: bool = False,
+        accumulate: Literal["avg", "best"] = "best",
         rouge_keys: Union[str, Tuple[str, ...]] = ("rouge1", "rouge2", "rougeL", "rougeLsum"),  # type: ignore
-        decimal_places: Optional[bool] = None,  # remove in v0.7
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
@@ -97,14 +102,11 @@ class ROUGEScore(Metric):
             process_group=process_group,
             dist_sync_fn=dist_sync_fn,
         )
-        if newline_sep is not None:
-            warnings.warn("Argument `newline_sep` is deprecated in v0.6 and will be removed in v0.7")
-        if decimal_places is not None:
-            warnings.warn("Argument `decimal_places` is deprecated in v0.6 and will be removed in v0.7")
-
         if use_stemmer or "rougeLsum" in rouge_keys:
             if not _NLTK_AVAILABLE:
-                raise ValueError("Stemmer and/or `rougeLsum` requires that nltk is installed. Use `pip install nltk`.")
+                raise ModuleNotFoundError(
+                    "Stemmer and/or `rougeLsum` requires that `nltk` is installed. Use `pip install nltk`."
+                )
             import nltk
 
         if not isinstance(rouge_keys, tuple):
@@ -113,31 +115,44 @@ class ROUGEScore(Metric):
             if key not in ALLOWED_ROUGE_KEYS:
                 raise ValueError(f"Got unknown rouge key {key}. Expected to be one of {ALLOWED_ROUGE_KEYS}")
 
+        if accumulate not in ALLOWED_ACCUMULATE_VALUES:
+            raise ValueError(
+                f"Got unknown accumulate value {accumulate}. Expected to be one of {ALLOWED_ACCUMULATE_VALUES}"
+            )
+
         self.rouge_keys = rouge_keys
         self.rouge_keys_values = [ALLOWED_ROUGE_KEYS[key] for key in rouge_keys]
         self.stemmer = nltk.stem.porter.PorterStemmer() if use_stemmer else None
+        self.accumulate = accumulate
 
         # Adding stated dynamically to prevent IndexError during sync function as some lists can be empty.
         for rouge_key in self.rouge_keys:
             for score in ["fmeasure", "precision", "recall"]:
                 self.add_state(f"{rouge_key}_{score}", [], dist_reduce_fx=None)
 
-    def update(self, preds: Union[str, List[str]], targets: Union[str, List[str]]) -> None:  # type: ignore
+    def update(  # type: ignore
+        self, preds: Union[str, Sequence[str]], target: Union[str, Sequence[str], Sequence[Sequence[str]]]
+    ) -> None:
         """Compute rouge scores.
 
         Args:
-            preds: An iterable of predicted sentences or a single predicted sentence.
-            targets: An iterable of target sentences or a single target sentence.
+            preds:
+                An iterable of predicted sentences or a single predicted sentence.
+            target:
+                An iterable of iterable of target sentences or an iterable
+                of target sentences or a single target sentence.
         """
+        if isinstance(target, list) and all(isinstance(tgt, str) for tgt in target):
+            target = [target] if isinstance(preds, str) else [[tgt] for tgt in target]
 
         if isinstance(preds, str):
             preds = [preds]
 
-        if isinstance(targets, str):
-            targets = [targets]
+        if isinstance(target, str):
+            target = [[target]]
 
         output: Dict[Union[int, str], List[Dict[str, Tensor]]] = _rouge_score_update(
-            preds, targets, self.rouge_keys_values, stemmer=self.stemmer
+            preds, target, self.rouge_keys_values, stemmer=self.stemmer, accumulate=self.accumulate
         )
         for rouge_key, metrics in output.items():
             for metric in metrics:
@@ -161,7 +176,6 @@ class ROUGEScore(Metric):
         # override to hash list objects.
         # this is a bug in the upstream pytorch release.
         hash_vals = [self.__class__.__name__]
-
         for key in self._defaults:
             value = getattr(self, key)
             if isinstance(value, list):
