@@ -22,8 +22,26 @@ from packaging.version import Version
 from pkg_resources import DistributionNotFound, get_distribution
 
 
+def _package_available(package_name: str) -> bool:
+    """Check if a package is available in your environment.
+
+    >>> _package_available('os')
+    True
+    >>> _package_available('bla')
+    False
+    """
+    try:
+        return find_spec(package_name) is not None
+    except AttributeError:
+        # Python 3.6
+        return False
+    except (ImportError, ModuleNotFoundError):
+        # Python 3.7+
+        return False
+
+
 def _module_available(module_path: str) -> bool:
-    """Check if a path is available in your environment.
+    """Check if a module path is available in your environment.
 
     >>> _module_available('os')
     True
@@ -32,14 +50,18 @@ def _module_available(module_path: str) -> bool:
     >>> _module_available('bla.bla')
     False
     """
+    module_names = module_path.split(".")
+    if not _package_available(module_names[0]):
+        return False
     try:
-        return find_spec(module_path) is not None
-    except AttributeError:
-        # Python 3.6
-        return False
-    except (ImportError, ModuleNotFoundError):
-        # Python 3.7+
+        module = import_module(module_names[0])
+    except ImportError:
         return False
+    for name in module_names[1:]:
+        if not hasattr(module, name):
+            return False
+        module = getattr(module, name)
+    return True
 
 
 def _compare_version(package: str, op: Callable, version: str) -> Optional[bool]:
@@ -76,22 +98,22 @@ _TORCH_GREATER_EQUAL_1_6: Optional[bool] = _compare_version("torch", operator.ge
 _TORCH_GREATER_EQUAL_1_7: Optional[bool] = _compare_version("torch", operator.ge, "1.7.0")
 _TORCH_GREATER_EQUAL_1_8: Optional[bool] = _compare_version("torch", operator.ge, "1.8.0")
 
-_LIGHTNING_AVAILABLE: bool = _module_available("pytorch_lightning")
-_JIWER_AVAILABLE: bool = _module_available("jiwer")
-_NLTK_AVAILABLE: bool = _module_available("nltk")
-_ROUGE_SCORE_AVAILABLE: bool = _module_available("rouge_score")
-_BERTSCORE_AVAILABLE: bool = _module_available("bert_score")
-_SCIPY_AVAILABLE: bool = _module_available("scipy")
-_TORCH_FIDELITY_AVAILABLE: bool = _module_available("torch_fidelity")
-_LPIPS_AVAILABLE: bool = _module_available("lpips")
-_PYCOCOTOOLS_AVAILABLE: bool = _module_available("pycocotools")
-_TORCHVISION_AVAILABLE: bool = _module_available("torchvision")
+_LIGHTNING_AVAILABLE: bool = _package_available("pytorch_lightning")
+_JIWER_AVAILABLE: bool = _package_available("jiwer")
+_NLTK_AVAILABLE: bool = _package_available("nltk")
+_ROUGE_SCORE_AVAILABLE: bool = _package_available("rouge_score")
+_BERTSCORE_AVAILABLE: bool = _package_available("bert_score")
+_SCIPY_AVAILABLE: bool = _package_available("scipy")
+_TORCH_FIDELITY_AVAILABLE: bool = _package_available("torch_fidelity")
+_LPIPS_AVAILABLE: bool = _package_available("lpips")
+_PYCOCOTOOLS_AVAILABLE: bool = _package_available("pycocotools")
+_TORCHVISION_AVAILABLE: bool = _package_available("torchvision")
 _TORCHVISION_GREATER_EQUAL_0_8: Optional[bool] = _compare_version("torchvision", operator.ge, "0.8.0")
-_TQDM_AVAILABLE: bool = _module_available("tqdm")
-_TRANSFORMERS_AVAILABLE: bool = _module_available("transformers")
+_TQDM_AVAILABLE: bool = _package_available("tqdm")
+_TRANSFORMERS_AVAILABLE: bool = _package_available("transformers")
 _TRANSFORMERS_AUTO_AVAILABLE = _module_available("transformers.models.auto")
-_PESQ_AVAILABLE: bool = _module_available("pesq")
-_SACREBLEU_AVAILABLE: bool = _module_available("sacrebleu")
-_REGEX_AVAILABLE: bool = _module_available("regex")
-_PYSTOI_AVAILABLE: bool = _module_available("pystoi")
-_FAST_BSS_EVAL_AVAILABLE: bool = _module_available("fast_bss_eval")
+_PESQ_AVAILABLE: bool = _package_available("pesq")
+_SACREBLEU_AVAILABLE: bool = _package_available("sacrebleu")
+_REGEX_AVAILABLE: bool = _package_available("regex")
+_PYSTOI_AVAILABLE: bool = _package_available("pystoi")
+_FAST_BSS_EVAL_AVAILABLE: bool = _package_available("fast_bss_eval")
